ensure_matching_blob_versioned_hashes

Function ensure_matching_blob_versioned_hashes 

pub fn ensure_matching_blob_versioned_hashes<T: Transaction + Typed2718, H>(
    block_body: &BlockBody<T, H>,
    cancun_sidecar_fields: Option<&CancunPayloadFields>,
) -> Result<(), PayloadError>
Ensures that the number of blob versioned hashes in EIP-4844 transactions in the block matches the number of hashes included in the separate block_versioned_hashes Cancun payload field on the sidecar.